==> 0.1.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/PalestineData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources.mussakhan
import kotlin.time.Duration

val palestineList = listOf(
    Recipe(
        title = "Mussakhan",
        description = "Chicken and Onions on a flatbread drenched in Oil, Sumac, and Almonds.",
        ingredients = listOf(

            "HEADER-Chicken Boil",
            "1 Whole Large Chicken, precut into ~6 pieces",
            "5 Cardamom Pods",
            "1 Tbsp Salt",

            "HEADER-Onions",
            "600ml Olive Oil",
            "12-14 Onions, Chopped",
            "1 Tsp Cumin, ground",
            "Black Pepper and Cinnamon, to Taste",

            "HEADER-To Serve",
            "150g Sumac",
            "6 Flatbreads",
            "1/2 Cup Pine Nuts",
            "3/4 Cup Almonds, sliced",
        ),
        instructions = listOf(
            "Boil the Chicken in water with 5 Cardamom Pods and 1 Tbsp of Salt.",
            "Heat Olive Oil in a large pan and saute Onions with Cumin [1 Tsp], Black Pepper, Cinnamon, and 1 Tbsp Salt.",
            "Preheat oven to 475F/240C",
            "Arrange Chicken on a baking tray. Cover with some Onion, sprinkle with Sumac, and bake for 5 minutes or until browned.",
            "To Serve, slather flatbreads with onions, scatter the rest of the Sumac along with all the Nuts [1/2 Cup] and Almonds [3/4 Cup].",
            "Eat with your hands."
        ),
        tags = mapOf(
            "Palestinian" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Baked" to TagType.TECHNIQUE,
            "Boiled" to TagType.TECHNIQUE,
            "Sauteed" to TagType.TECHNIQUE,
            "Savory" to TagType.FLAVOUR,
        ),
        prepTime = Duration.parse("20m"),
        cookTime = Duration.parse("1h 15m"),
        servings = "Serves 6 to 8 People",
        image = Res.drawable.mussakhan
    )
)

==> 0.2.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/PalestineData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources.mussakhan
import kotlin.time.Duration

val palestineList = listOf(
    Recipe(
        title = "Mussakhan",
        description = "Chicken and Onions on a flatbread drenched in Oil, Sumac, and Almonds.",
        ingredients = listOf(

            "HEADER-Chicken Boil",
            "1 Whole Large Chicken, precut into ~6 pieces",
            "5 Cardamom Pods",
            "1 Tbsp Salt",

            "HEADER-Onions",
            "600ml Olive Oil",
            "12-14 Onions, Chopped",
            "1 Tsp Cumin, ground",
            "Black Pepper and Cinnamon, to Taste",

            "HEADER-To Serve",
            "150g Sumac",
            "6 Flatbreads",
            "1/2 Cup Pine Nuts",
            "3/4 Cup Almonds, sliced",
        ),
        instructions = listOf(
            "Boil the Chicken in water with 5 Cardamom Pods and 1 Tbsp of Salt.",
            "Heat Olive Oil in a large pan and saute Onions with Cumin [1 Tsp], Black Pepper, Cinnamon, and 1 Tbsp Salt.",
            "Preheat oven to 475F/240C",
            "Arrange Chicken on a baking tray. Cover with some Onion, sprinkle with Sumac, and bake for 5 minutes or until browned.",
            "To Serve, slather flatbreads with onions, scatter the rest of the Sumac along with all the Nuts [1/2 Cup] and Almonds [3/4 Cup].",
            "Eat with your hands."
        ),
        tags = mapOf(
            "Palestine" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Baked" to TagType.TECHNIQUE,
            "Boiled" to TagType.TECHNIQUE,
            "Sauteed" to TagType.TECHNIQUE,
            "Savory" to TagType.FLAVOUR,
        ),
        prepTime = Duration.parse("20m"),
        cookTime = Duration.parse("1h 15m"),
        servings = "Serves 6 to 8 People",
        image = Res.drawable.mussakhan
    )
)
